@@ -3,11 +3,16 @@ get_contrast_data_character <- function(model,
                                         variable,
                                         cross,
                                         first_cross,
+                                        modeldata = NULL,
                                         ...) {
 
     # factors store all levels, but characters do not, so we need to extract the
     # original data from the model.
-    tmp <- modeldata <- get_modeldata(model)
+    if (is.null(modeldata)) {
+        tmp <- modeldata <- get_modeldata(model, additional_variables = FALSE)
+    } else {
+        tmp <- modeldata
+    }
 
     # unsupported by insight (e.g., numpyro)
     if (is.null(tmp)) {
