@@ -2,8 +2,6 @@
 #' @export
 get_predict.rq <- function(model,
                            newdata = insight::get_data(model),
-                           vcov = NULL,
-                           conf_level = 0.95,
                            type = NULL,
                            ...) {
 
