@@ -4,19 +4,27 @@
 #' @import data.table
 utils::globalVariables(c(
 "..bycols",
+"..to_keep",
 "..cols",
 "..idx_by",
 "..idx_hi",
+"..cl",
 "..idx_lo",
+".data",
 "..idx_or",
 "..idx",
 "..idx1",
 "..idx2",
+"..nonfocal",
+"rowidcf",
 "elast",
 "..tmp",
 "..variables_grid",
 "..w",
+"marginaleffects_lab",
+"marginaleffects_ter",
 ".",
+"tmp_idx",
 "comparison",
 "condition_variable",
 "conf_int",
@@ -34,7 +42,6 @@ utils::globalVariables(c(
 "group",
 "logLik",
 "m",
-"marginaleffects_eps",
 "marginaleffects_function",
 "marginaleffects_wts_internal",
 "marginalmean",
