@@ -13,36 +13,36 @@
 #' * <https://vincentarelbundock.github.io/marginaleffects/articles/predictions.html>
 #' * <https://vincentarelbundock.github.io/marginaleffects/>
 #'
+#' @rdname predictions
 #' @details
 #' The `newdata` argument, the `tidy()` function, and `datagrid()` function can be used to control the kind of predictions to report:
-#' 
+#'
 #' * Average Predictions
 #' * Predictions at the Mean
 #' * Predictions at User-Specified values (aka Predictions at Representative values).
 #'
-#' When possible, `predictions()` delegates the computation of confidence
-#' intervals to the `insight::get_predicted()` function, which uses back
-#' transformation to produce adequate confidence intervals on the scale
-#' specified by the `type` argument. When this is not possible, `predictions()`
-#' uses the Delta Method to compute standard errors around adjusted
-#' predictions, and builds symmetric confidence intervals. These naive symmetric
-#' intervals may not always be appropriate. For instance, they may stretch beyond
-#' the bounds of a binary response variables.
-#' @inheritParams slopes
+#' For `glm()` or `gam::gam()` models with `type=NULL` (the default), `predictions()` first predicts on the link scale, and then backtransforms the estimates and confidence intervals. This implies that the `estimate` produced by `avg_predictions()` will not be exactly equal to the average of the `estimate` column produced by `predictions()`. Users can circumvent this behavior and average predictions directly on the response scale by setting `type="response"` explicitly. With `type="response"`, the intervals are symmetric and may have undesirable properties (e.g., stretching beyond the `[0,1]` bounds for a binary outcome regression).
+#' 
 #' @param model Model object
-#' @param variables `NULL`, character vector, or named list. The subset of variables to use for creating a counterfactual grid of predictions. The entire dataset replicated for each unique combination of the variables in this list. See the Examples section below.
-#' * Warning: This can use a lot of memory if there are many variables and values, and when the dataset is large.
-#' * `NULL`: computes one prediction per row of `newdata`
-#' * Named list: names identify the subset of variables of interest and their values. For numeric variables, the `variables` argument supports functions and string shortcuts:
-#'   - A function which returns a numeric value
-#'   - Numeric vector: Contrast between the 2nd element and the 1st element of the `x` vector.
-#'   - "iqr": Contrast across the interquartile range of the regressor.
-#'   - "sd": Contrast across one standard deviation around the regressor mean.
-#'   - "2sd": Contrast across two standard deviations around the regressor mean.
-#'   - "minmax": Contrast between the maximum and the minimum values of the regressor.
-#'   - "threenum": mean and 1 standard deviation on both sides
-#'   - "fivenum": Tukey's five numbers
-#' #' @param newdata `NULL`, data frame, string, or `datagrid()` call. Determines the grid of predictors on which we make predictions.
+#' @param variables Counterfactual variables.
+#' * Output:
+#'   - `predictions()`: The entire dataset is replicated once for each unique combination of `variables`, and predictions are made.
+#'   - `avg_predictions()`: The entire dataset is replicated, predictions are made, and they are marginalized by `variables` categories.
+#'   - Warning: This can be expensive in large datasets.
+#'   - Warning: Users who need "conditional" predictions should use the `newdata` argument instead of `variables`.
+#' * Input:
+#'   - `NULL`: computes one prediction per row of `newdata`
+#'   - Character vector: the dataset is replicated once of every combination of unique values of the variables identified in `variables`.
+#'   - Named list: names identify the subset of variables of interest and their values. For numeric variables, the `variables` argument supports functions and string shortcuts:
+#'     + A function which returns a numeric value
+#'     + Numeric vector: Contrast between the 2nd element and the 1st element of the `x` vector.
+#'     + "iqr": Contrast across the interquartile range of the regressor.
+#'     + "sd": Contrast across one standard deviation around the regressor mean.
+#'     + "2sd": Contrast across two standard deviations around the regressor mean.
+#'     + "minmax": Contrast between the maximum and the minimum values of the regressor.
+#'     + "threenum": mean and 1 standard deviation on both sides
+#'     + "fivenum": Tukey's five numbers
+#' @param newdata Grid of predictor values at which we evaluate predictions.
 #' + `NULL` (default): Predictions for each observed value in the original dataset.
 #' + data frame: Predictions for each row of the `newdata` data frame.
 #' + string:
@@ -54,15 +54,22 @@
 #' + [datagrid()] call to specify a custom grid of regressors. For example:
 #'   - `newdata = datagrid(cyl = c(4, 6))`: `cyl` variable equal to 4 and 6 and other regressors fixed at their means or modes.
 #'   - See the Examples section and the [datagrid()] documentation.
-#' @param byfun A function such as `mean()` or `sum()` used to aggregate 
+#' @param byfun A function such as `mean()` or `sum()` used to aggregate
 #' estimates within the subgroups defined by the `by` argument. `NULL` uses the
 #' `mean()` function. Must accept a numeric vector and return a single numeric
 #' value. This is sometimes used to take the sum or mean of predicted
 #' probabilities across outcome or predictor
 #' levels. See examples section.
-#' @param transform_post (experimental) A function applied to unit-level adjusted predictions and confidence intervals just before the function returns results. For bayesian models, this function is applied to individual draws from the posterior distribution, before computing summaries.
+#' @param type string indicates the type (scale) of the predictions used to
+#' compute contrasts or slopes. This can differ based on the model
+#' type, but will typically be a string such as: "response", "link", "probs",
+#' or "zero". When an unsupported string is entered, the model-specific list of
+#' acceptable values is returned in an error message. When `type` is `NULL`, the
+#' default value is used. This default is the first model-related row in
+#' the `marginaleffects:::type_dictionary` dataframe. See the details section for a note on backtransformation.
+#' @param transform_post A function applied to unit-level adjusted predictions and confidence intervals just before the function returns results. For bayesian models, this function is applied to individual draws from the posterior distribution, before computing summaries.
 #'
-#' @inheritParams comparisons
+#' @template deltamethod
 #' @template model_specific_arguments
 #' @template bayesian
 #'
@@ -71,9 +78,12 @@
 #' * `type`: prediction type, as defined by the `type` argument
 #' * `group`: (optional) value of the grouped outcome (e.g., categorical outcome models)
 #' * `estimate`: predicted outcome
-#' * `std.error`: standard errors computed by the `insight::get_predicted` function or, if unavailable, via `marginaleffects` delta method functionality.
+#' * `std.error`: standard errors computed using the delta method.
 #' * `conf.low`: lower bound of the confidence interval (or equal-tailed interval for bayesian models)
 #' * `conf.high`: upper bound of the confidence interval (or equal-tailed interval for bayesian models)
+#'
+#' See `?print.marginaleffects` for printing options.
+#'
 #' @examples
 #' # Adjusted Prediction for every row of the original dataset
 #' mod <- lm(mpg ~ hp + factor(cyl), data = mtcars)
@@ -85,13 +95,13 @@
 #'
 #' m <- lm(mpg ~ hp + drat + factor(cyl) + factor(am), data = mtcars)
 #' predictions(m, newdata = datagrid(FUN_factor = unique, FUN_numeric = median))
-#' 
+#'
 #' # Average Adjusted Predictions (AAP)
 #' library(dplyr)
 #' mod <- lm(mpg ~ hp * am * vs, mtcars)
 #'
 #' avg_predictions(mod)
-#' 
+#'
 #' predictions(mod, by = "am")
 #'
 #' # Conditional Adjusted Predictions
@@ -99,38 +109,41 @@
 #'
 #' # Counterfactual predictions with the `variables` argument
 #' # the `mtcars` dataset has 32 rows
-#' 
+#'
 #' mod <- lm(mpg ~ hp + am, data = mtcars)
 #' p <- predictions(mod)
 #' head(p)
 #' nrow(p)
-#' 
+#'
+#' # average counterfactual predictions
+#' avg_predictions(mod, variables = "am")
+#'
 #' # counterfactual predictions obtained by replicating the entire for different
 #' # values of the predictors
 #' p <- predictions(mod, variables = list(hp = c(90, 110)))
 #' nrow(p)
-#' 
+#'
 #'
 #' # hypothesis test: is the prediction in the 1st row equal to the prediction in the 2nd row
 #' mod <- lm(mpg ~ wt + drat, data = mtcars)
-#' 
+#'
 #' predictions(
 #'     mod,
 #'     newdata = datagrid(wt = 2:3),
 #'     hypothesis = "b1 = b2")
-#' 
+#'
 #' # same hypothesis test using row indices
 #' predictions(
 #'     mod,
 #'     newdata = datagrid(wt = 2:3),
 #'     hypothesis = "b1 - b2 = 0")
-#' 
+#'
 #' # same hypothesis test using numeric vector of weights
 #' predictions(
 #'     mod,
 #'     newdata = datagrid(wt = 2:3),
 #'     hypothesis = c(1, -1))
-#' 
+#'
 #' # two custom contrasts using a matrix of weights
 #' lc <- matrix(c(
 #'     1, -1,
@@ -140,34 +153,36 @@
 #'     mod,
 #'     newdata = datagrid(wt = 2:3),
 #'     hypothesis = lc)
-#' 
-#' 
+#'
+#'
 #' # `by` argument
 #' mod <- lm(mpg ~ hp * am * vs, data = mtcars)
-#' predictions(mod, by = c("am", "vs")) 
-#' 
+#' predictions(mod, by = c("am", "vs"))
+#'
 #' library(nnet)
 #' nom <- multinom(factor(gear) ~ mpg + am * vs, data = mtcars, trace = FALSE)
-#' 
+#'
 #' # first 5 raw predictions
 #' predictions(nom, type = "probs") |> head()
-#' 
+#'
 #' # average predictions
 #' avg_predictions(nom, type = "probs", by = "group")
-#' 
+#'
 #' by <- data.frame(
 #'     group = c("3", "4", "5"),
 #'     by = c("3,4", "3,4", "5"))
-#' 
+#'
 #' predictions(nom, type = "probs", by = by)
-#' 
+#'
 #' # sum of predicted probabilities for combined response levels
 #' mod <- multinom(factor(cyl) ~ mpg + am, data = mtcars, trace = FALSE)
 #' by <- data.frame(
 #'     by = c("4,6", "4,6", "8"),
 #'     group = as.character(c(4, 6, 8)))
 #' predictions(mod, newdata = "mean", byfun = sum, by = by)
-#' 
+#'
+#' @inheritParams slopes
+#' @inheritParams comparisons
 #' @export
 predictions <- function(model,
                         newdata = NULL,
@@ -187,29 +202,61 @@ predictions <- function(model,
     # order of the first few paragraphs is important
     # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
     scall <- substitute(newdata)
-    if (is.call(scall)) {
-        lcall <- as.list(scall)
-        fun_name <- as.character(scall)[1]
-        if (fun_name %in% c("datagrid", "datagridcf", "typical", "counterfactual")) {
-            if (!any(c("model", "newdata") %in% names(lcall))) {
-                lcall <- c(lcall, list("model" = model))
-                newdata <- eval.parent(as.call(lcall))
-            }
-        } else if (fun_name == "visualisation_matrix") {
-            if (!"x" %in% names(lcall)) {
-                lcall <- c(lcall, list("x" = get_modeldata))
-                newdata <- eval.parent(as.call(lcall))
-            }
-        }
+    newdata <- sanitize_newdata_call(scall, newdata, model)
+
+    # build call: match.call() doesn't work well in *apply()
+    call_attr <- c(list(
+        name = "predictions",
+        model = model,
+        newdata = newdata,
+        variables = variables,
+        vcov = vcov,
+        conf_level = conf_level,
+        type = type,
+        by = by,
+        byfun = byfun,
+        wts = wts,
+        transform_post = transform_post,
+        hypothesis = hypothesis,
+        df = df),
+        list(...))
+    call_attr <- do.call("call", call_attr)
+
+    # multiple imputation
+    if (inherits(model, "mira")) {
+        out <- process_imputation(model, call_attr)
+        return(out)
     }
 
-
-    # extracting modeldata repeatedly is slow. this allows marginalmeans to pass modeldata to predictions.
+    # extracting modeldata repeatedly is slow.
+    # checking dots allows marginalmeans to pass modeldata to predictions.
     dots <- list(...)
     if ("modeldata" %in% names(dots)) {
         modeldata <- dots[["modeldata"]]
     } else {
-        modeldata <- get_modeldata(model)
+        if (isTRUE(checkmate::check_character(by))) {
+            addvar <- by
+        } else if (isTRUE(checkmate::check_data_frame(by))) {
+            addvar <- colnames(by)
+        } else {
+            addvar <- FALSE
+        }
+        modeldata <- get_modeldata(model, additional_variables = addvar)
+    }
+
+    # if type is NULL, we backtransform if relevant
+    if ((is.null(type)) && is.null(transform_post) && isTRUE(class(model)[1] %in% c("glm", "Gam"))) {
+        dict <- subset(type_dictionary, class == class(model)[1])$type
+        type <- sanitize_type(model = model, type = type)
+        linv <- tryCatch(insight::link_inverse(model), error = function(e) NULL)
+        if (isTRUE(type == "response") && isTRUE("link" %in% dict) && is.function(linv)) {
+            type <- "link"
+            transform_post <- linv
+        } else {
+            type <- sanitize_type(model = model, type = type)
+        }
+    } else {
+        type <- sanitize_type(model = model, type = type)
     }
 
     # do not check the model because `insight` supports more models than `marginaleffects`
@@ -217,17 +264,6 @@ predictions <- function(model,
 
     # input sanity checks
     checkmate::assert_number(df, lower = 1)
-    if (is.infinite(df)) {
-        ci_method <- "normal"
-    } else {
-        ci_method <- "wald"
-        df_auto <- insight::get_df(model, type = "wald")
-        if (!all(df == df_auto)) {
-            msg <- 'The `df` argument does not match the output of `insight::get_df(model, type = "wald")`. The p values and confidence intervals may not use the same degrees of freedom.'
-            insight::format_warning(msg)
-        }
-    }
-
 
     transform_post <- sanitize_transform_post(transform_post)
     sanity_dots(model = model, ...)
@@ -243,7 +279,6 @@ predictions <- function(model,
     hypothesis_null <- tmp$hypothesis_null
 
     conf_level <- sanitize_conf_level(conf_level, ...)
-    type <- sanitize_type(model = model, type = type, calling_function = "predictions")
     newdata <- sanitize_newdata(
         model = model,
         newdata = newdata,
@@ -263,6 +298,7 @@ predictions <- function(model,
             variables = variables,
             model = model,
             newdata = newdata,
+            modeldata = modeldata,
             calling_function = "predictions"
             )$conditional
         for (v in tmp) {
@@ -270,7 +306,7 @@ predictions <- function(model,
         }
         newdata <- do.call("datagrid", args)
         # the original rowids are no longer valid after averaging et al.
-        newdata[["rowid"]] <- NULL 
+        newdata[["rowid"]] <- NULL
     }
 
     character_levels <- attr(newdata, "newdata_character_levels")
@@ -294,12 +330,14 @@ predictions <- function(model,
         newdata[["idx"]] <- NULL
     }
 
+    # padding destroys `newdata` attributes, so we save them
+    newdata_attr_cache <- get_marginaleffects_attributes(newdata, include_regex = "^newdata")
+
     # mlogit uses an internal index that is very hard to track, so we don't
     # support `newdata` and assume no padding the `idx` column is necessary for
     # `get_predict` but it breaks binding, so we can't remove it in
     # sanity_newdata and we can't rbind it with padding
-
-    # pad factors: `get_predicted/model.matrix` break when factor levels are missing
+    # pad factors: `model.matrix` breaks when factor levels are missing
     if (inherits(model, "mlogit")) {
         padding <- data.frame()
     } else {
@@ -329,26 +367,19 @@ predictions <- function(model,
     }
 
 
-
     # main estimation
-    J <- NULL
-
     args <- list(
         model = model,
         newdata = newdata,
-        vcov = vcov_tmp,
-        conf_level = conf_level,
         type = type,
         hypothesis = hypothesis,
         by = by,
-        byfun = byfun,
-        ci_method = ci_method)
+        byfun = byfun)
 
     args <- utils::modifyList(args, dots)
     tmp <- do.call(get_predictions, args)
 
     # two cases when tmp is a data.frame
-    # insight::get_predicted gets us Predicted et al. but now rowid
     # get_predict gets us rowid with the original rows
     if (inherits(tmp, "data.frame")) {
         setnames(tmp,
@@ -396,8 +427,8 @@ predictions <- function(model,
     }
 
     V <- NULL
+    J <- NULL
     if (!isFALSE(vcov)) {
-
         V <- get_vcov(model, vcov = vcov, ...)
 
         # Delta method
@@ -405,7 +436,7 @@ predictions <- function(model,
             if (isTRUE(checkmate::check_matrix(V))) {
                 # vcov = FALSE to speed things up
                 fun <- function(...) {
-                    get_predictions(..., verbose = FALSE, vcov = FALSE)$estimate
+                    get_predictions(..., verbose = FALSE)$estimate
                 }
                 args <- list(
                     model,
@@ -414,14 +445,14 @@ predictions <- function(model,
                     type = type,
                     FUN = fun,
                     J = J,
-                    eps = 1e-4, # avoid pushing through ...
                     hypothesis = hypothesis,
                     by = by,
-                    byfun = byfun,
-                    conf_level = conf_level)
+                    byfun = byfun)
                 args <- utils::modifyList(args, dots)
                 se <- do.call(get_se_delta, args)
                 if (is.numeric(se) && length(se) == nrow(tmp)) {
+                    J <- attr(se, "jacobian")
+                    attr(se, "jacobian") <- NULL
                     tmp[["std.error"]] <- se
                 }
             }
@@ -439,9 +470,7 @@ predictions <- function(model,
             ...)
     }
 
-    out <- data.table(tmp)
-
-    setDF(out)
+    out <- data.frame(tmp)
 
     # save weights as attribute and not column
     marginaleffects_wts_internal <- out[["marginaleffects_wts_internal"]]
@@ -454,7 +483,7 @@ predictions <- function(model,
         bycols <- by
     }
 
-    stubcols <- c( 
+    stubcols <- c(
         "rowid", "rowidcf", "type", "term", "group", "hypothesis",
         bycols,
         "estimate", "std.error", "statistic", "p.value", "conf.low",
@@ -473,9 +502,7 @@ predictions <- function(model,
     out <- backtransform(out, transform_post = transform_post)
 
     class(out) <- c("predictions", class(out))
-    out <- set_marginaleffects_attributes(
-        out,
-        get_marginaleffects_attributes(newdata, include_regex = "^newdata"))
+    out <- set_marginaleffects_attributes(out, attr_cache = newdata_attr_cache)
     attr(out, "model") <- model
     attr(out, "type") <- type
     attr(out, "model_type") <- class(model)[1]
@@ -486,7 +513,7 @@ predictions <- function(model,
     attr(out, "weights") <- marginaleffects_wts_internal
     attr(out, "conf_level") <- conf_level
     attr(out, "by") <- by
-    attr(out, "call") <- match.call()
+    attr(out, "call") <- call_attr
     attr(out, "transform_post_label") <- names(transform_post)[1]
     attr(out, "transform_post") <- transform_post[[1]]
     # save newdata for use in recall()
@@ -513,8 +540,6 @@ predictions <- function(model,
 # wrapper used only for standard_error_delta
 get_predictions <- function(model,
                             newdata,
-                            vcov,
-                            conf_level,
                             type,
                             by = NULL,
                             byfun = byfun,
@@ -526,8 +551,6 @@ get_predictions <- function(model,
     out <- myTryCatch(get_predict(
         model,
         newdata = newdata,
-        vcov = vcov,
-        conf_level = conf_level,
         type = type,
         ...))
 
@@ -535,10 +558,11 @@ get_predictions <- function(model,
     if (inherits(out$value, "data.frame")) {
         out <- out$value
     } else {
-        msg <- "Unable to compute predicted values with this model. You can try to supply a different dataset to the `newdata` argument. If this does not work, you can file a report on the Github Issue Tracker: https://github.com/vincentarelbundock/marginaleffects/issues"
+        msg <- "Unable to compute predicted values with this model. You can try to supply a different dataset to the `newdata` argument."
         if (!is.null(out$error)) {
-            msg <- c(msg, "", paste("This error was also raised:", "", out$error$message))
+            msg <- c(paste(msg, "This error was also raised:"), "", out$error$message)
         }
+        msg <- c(msg, "", "Bug Tracker: https://github.com/vincentarelbundock/marginaleffects/issues")
         insight::format_error(msg)
     }
 
@@ -549,7 +573,7 @@ get_predictions <- function(model,
     # extract attributes before setDT
     draws <- attr(out, "posterior_draws")
 
-    setDT(out)
+    data.table::setDT(out)
 
     # unpad factors before averaging
     # trust `newdata` rowid more than `out` because sometimes `get_predict()` will add a positive index even on padded data
@@ -569,7 +593,12 @@ get_predictions <- function(model,
     mergein <- setdiff(colnames(newdata), colnames(out))
     if ("rowid" %in% colnames(out) && "rowid" %in% colnames(newdata) && length(mergein) > 0) {
         idx <- c("rowid", mergein)
-        tmp <- data.table(newdata)[, ..idx]
+
+        if (!data.table::is.data.table(newdata)) {
+          tmp <- data.table::data.table(newdata)[, ..idx]
+        } else {
+          tmp <- newdata[, ..idx]
+        }
         # TODO: this breaks in mclogit. maybe there's a more robust merge
         # solution for weird grouped data. But it seems fine because
         # `predictions()` output does include the original predictors.
@@ -619,19 +648,14 @@ avg_predictions <- function(model,
     # order of the first few paragraphs is important
     # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
     scall <- substitute(newdata)
-    if (is.call(scall)) {
-        lcall <- as.list(scall)
-        fun_name <- as.character(scall)[1]
-        if (fun_name %in% c("datagrid", "datagridcf", "typical", "counterfactual")) {
-            if (!any(c("model", "newdata") %in% names(lcall))) {
-                lcall <- c(lcall, list("model" = model))
-                newdata <- eval.parent(as.call(lcall))
-            }
-        } else if (fun_name == "visualisation_matrix") {
-            if (!"x" %in% names(lcall)) {
-                lcall <- c(lcall, list("x" = get_modeldata))
-                newdata <- eval.parent(as.call(lcall))
-            }
+    newdata <- sanitize_newdata_call(scall, newdata, model)
+
+    # group by focal variable automatically unless otherwise stated
+    if (isTRUE(by)) {
+        if (isTRUE(checkmate::check_character(variables))) {
+            by <- variables
+        } else if (isTRUE(checkmate::check_list(variables, names = "named"))) {
+            by <- names(variables)
         }
     }
 
@@ -660,8 +684,5 @@ avg_predictions <- function(model,
         df = df,
         ...)
 
-    # overwrite call because otherwise we get the symbosl sent to predictions()
-    attr(out, "call") <- match.call()
-
     return(out)
-}
\ No newline at end of file
+}
