@@ -2,17 +2,17 @@
 #'
 #' @description
 #' Partial derivative of the regression equation with respect to a regressor of interest.
-#' 
+#'
 #' * `slopes()`: unit-level (conditional) estimates.
 #' * `avg_slopes()`: average (marginal) estimates.
-#' 
+#'
 #' The `newdata` argument and the `datagrid()` function can be used to control where statistics are evaluated in the predictor space: "at observed values", "at the mean", "at representative values", etc.
-#' 
+#'
 #' See the slopes vignette and package website for worked examples and case studies:
-#' 
+#'
 #' * <https://vincentarelbundock.github.io/marginaleffects/articles/slopes.html>
 #' * <https://vincentarelbundock.github.io/marginaleffects/>
-#' 
+#'
 #' @details
 #' A "slope" or "marginal effect" is the partial derivative of the regression equation
 #' with respect to a variable in the model. This function uses automatic
@@ -20,23 +20,12 @@
 #' including non-linear models with transformations (e.g., polynomials).
 #' Uncertainty estimates are computed using the delta method.
 #'
-#' Numerical derivatives for the `slopes` function are calculated
-#' using a simple epsilon difference approach: \eqn{\partial Y / \partial X = (f(X + \varepsilon) - f(X)) / \varepsilon}{dY/dX = (f(X + e) - f(X)) / e},
-#' where f is the `predict()` method associated with the model class, and
-#' \eqn{\varepsilon}{e} is determined by the `eps` argument.
-#'
-#' Warning: Some models are particularly sensitive to `eps`, so it is good
-#' practice to try different values of this argument.
-#'
-#' Standard errors for the slopes are obtained using the Delta
-#' method. See the "Standard Errors" vignette on the package website for
-#' details (link above).
 #' @param model Model object
-#' @param variables `NULL` or character vector. The subset of variables for which to compute slopes.
-#' * `NULL`: compute contrasts for all the variables in the model object (can be slow). 
+#' @param variables Focal variables
+#' * `NULL`: compute slopes or comparisons for all the variables in the model object (can be slow).
 #' * Character vector: subset of variables (usually faster).
-#' @param newdata `NULL`, data frame, string, or `datagrid()` call. Determines the predictor values for which to compute slopes.
-#' + `NULL` (default): Unit-level slopes each observed value in the original dataset.
+#' @param newdata Grid of predictor values at which we evaluate the slopes.
+#' + `NULL` (default): Unit-level slopes for each observed value in the original dataset.
 #' + data frame: Unit-level slopes for each row of the `newdata` data frame.
 #' + [datagrid()] call to specify a custom grid of regressors. For example:
 #'   - `newdata = datagrid(cyl = c(4, 6))`: `cyl` variable equal to 4 and 6 and other regressors fixed at their means or modes.
@@ -75,10 +64,10 @@
 #' contrasts or slopes. These weights only affect the averaging in
 #' `avg_*()` or with the `by` argument, and not the unit-level estimates themselves.
 #' + string: column name of the weights variable in `newdata`. When supplying a column name to `wts`, it is recommended to supply the original data (including the weights variable) explicitly to `newdata`.
-#' + numeric: vector of length equal to the number of rows in the original data or in `newdata` (if supplied). 
+#' + numeric: vector of length equal to the number of rows in the original data or in `newdata` (if supplied).
 #' @param hypothesis specify a hypothesis test or custom contrast using a numeric value, vector, or matrix, a string, or a string formula.
 #' + Numeric:
-#'   - Single value: the null hypothesis used in the computation of Z and p (before applying `transform_post`). 
+#'   - Single value: the null hypothesis used in the computation of Z and p (before applying `transform_post`).
 #'   - Vector: Weights to compute a linear combination of (custom contrast between) estimates. Length equal to the number of rows generated by the same function call, but without the `hypothesis` argument.
 #'   - Matrix: Each column is a vector of weights, as describe above, used to compute a distinct linear combination of (contrast between) estimates. The column names of the matrix are used as labels in the output.
 #' + String formula to specify linear or non-linear hypothesis tests. If the `term` column uniquely identifies rows, terms can be used in the formula. Otherwise, use `b1`, `b2`, etc. to identify the position of each parameter. Examples:
@@ -108,6 +97,12 @@
 #' arguments.
 #' @inheritParams comparisons
 #'
+#' @details
+#' Numerical derivatives for the `slopes` function are calculated
+#' using a simple epsilon difference approach: \eqn{\partial Y / \partial X = (f(X + \varepsilon/2) - f(X+\varepsilon/2)) / \varepsilon}{dY/dX = (f(X + e/2) - f(X-e/2)) / e},
+#' where f is the `predict()` method associated with the model class, and
+#' \eqn{\varepsilon}{e} is determined by the `eps` argument.
+#' @template deltamethod
 #' @template model_specific_arguments
 #' @template bayesian
 #'
@@ -118,6 +113,9 @@
 #' * `term`: the variable whose marginal effect is computed
 #' * `dydx`: slope of the outcome with respect to the term, for a given combination of predictor values
 #' * `std.error`: standard errors computed by via the delta method.
+#'
+#' See `?print.marginaleffects` for printing options.
+#'
 #' @examplesIf interactive()
 #' @examples
 #'
@@ -129,7 +127,7 @@
 #' # Average Marginal Effect (AME)
 #' avg_slopes(mod, by = TRUE)
 #'
-#' 
+#'
 #' # Marginal Effect at the Mean (MEM)
 #' slopes(mod, newdata = datagrid())
 #'
@@ -164,19 +162,19 @@
 #'     mod,
 #'     newdata = "mean",
 #'     hypothesis = "wt = drat")
-#' 
+#'
 #' # same hypothesis test using row indices
 #' slopes(
 #'     mod,
 #'     newdata = "mean",
 #'     hypothesis = "b1 - b2 = 0")
-#' 
+#'
 #' # same hypothesis test using numeric vector of weights
 #' slopes(
 #'     mod,
 #'     newdata = "mean",
 #'     hypothesis = c(1, -1))
-#' 
+#'
 #' # two custom contrasts using a matrix of weights
 #' lc <- matrix(c(
 #'     1, -1,
@@ -187,7 +185,7 @@
 #'     mod,
 #'     newdata = "mean",
 #'     hypothesis = lc)
-#' 
+#'
 #' @export
 slopes <- function(model,
                    newdata = NULL,
@@ -208,22 +206,25 @@ slopes <- function(model,
     # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
     # should probably not be nested too deeply in the call stack since we eval.parent() (not sure about this)
     scall <- substitute(newdata)
-    if (is.call(scall)) {
-        lcall <- as.list(scall)
-        fun_name <- as.character(scall)[1]
-        if (fun_name %in% c("datagrid", "datagridcf", "typical", "counterfactual")) {
-            if (!any(c("model", "newdata") %in% names(lcall))) {
-                lcall <- c(lcall, list("model" = model))
-                newdata <- eval.parent(as.call(lcall))
-            }
-        } else if (fun_name == "visualisation_matrix") {
-            if (!"x" %in% names(lcall)) {
-                lcall <- c(lcall, list("x" = get_modeldata(model)))
-                newdata <- eval.parent(as.call(lcall))
-            }
-        }
+    newdata <- sanitize_newdata_call(scall, newdata, model)
 
-    }
+    # build call: match.call() doesn't work well in *apply()
+    call_attr <- c(list(
+        name = "slopes",
+        model = model,
+        newdata = newdata,
+        variables = variables,
+        type = type,
+        vcov = vcov,
+        by = by,
+        conf_level = conf_level,
+        slope = slope,
+        wts = wts,
+        hypothesis = hypothesis,
+        df = df,
+        eps = eps),
+        list(...))
+    call_attr <- do.call("call", call_attr)
 
     # slopes() does not support a named list of variables like comparisons()
     checkmate::assert_character(variables, null.ok = TRUE)
@@ -235,7 +236,7 @@ slopes <- function(model,
     # sanity checks and pre-processing
     model <- sanitize_model(model = model, newdata = newdata, wts = wts, vcov = vcov, calling_function = "marginaleffects", ...)
     sanity_dots(model = model, calling_function = "marginaleffects", ...)
-    type <- sanitize_type(model = model, type = type, calling_function = "marginaleffects")
+    type <- sanitize_type(model = model, type = type)
 
     ############### sanity checks are over
 
@@ -244,12 +245,12 @@ slopes <- function(model,
         FUN = slopes,
         model = model, newdata = newdata, vcov = vcov, variables = variables, type = type,
         conf_level = conf_level,
+        by = by,
         wts = wts, slope = slope, hypothesis = hypothesis, ...)
     if (!is.null(out)) {
         return(out)
     }
 
-
     out <- comparisons(
         model,
         newdata = newdata,
@@ -262,26 +263,25 @@ slopes <- function(model,
         df = df,
         by = by,
         eps = eps,
-        contrast_factor = "reference",
-        contrast_numeric = 1,
-        # hard-coded. Users should use comparisons() for more flexibility
         transform_pre = slope,
         cross = FALSE,
         # secret arguments
         internal_call = TRUE,
         ...)
 
-    setDT(out)
+    data.table::setDT(out)
 
     # clean columns
     stubcols <- c("rowid", "type", "group", "term", "contrast", "hypothesis", "dydx", "estimate", "std.error", "statistic", "p.value", "conf.low", "conf.high",
                   sort(grep("^predicted", colnames(newdata), value = TRUE)))
     cols <- intersect(stubcols, colnames(out))
     cols <- unique(c(cols, colnames(out)))
-    out <- out[, ..cols]
+    if (length(setdiff(names(out), cols)) > 0L) {
+      out[, setdiff(names(out), cols) := NULL]
+    }
 
     if ("group" %in% colnames(out) && all(out$group == "main_marginaleffect")) {
-        out$group <- NULL
+        out[, "group" := NULL]
     }
 
     # return contrast column only when relevant
@@ -294,12 +294,12 @@ slopes <- function(model,
     }
 
     attr(out, "vcov.type") <- get_vcov_label(vcov)
-    attr(out, "call") <- match.call()
     # save newdata=datagrid() for use in recall()
     attr(out, "newdata") <- newdata
+    attr(out, "call") <- call_attr
 
     # class
-    setDF(out)
+    data.table::setDF(out)
     class(out) <- setdiff(class(out), "comparisons")
     class(out) <- c("slopes", "marginaleffects", class(out))
     return(out)
@@ -316,7 +316,7 @@ meffects <- slopes
 
 
 #' `marginaleffects()` is an alias to `slopes()`
-#' 
+#'
 #' This alias is kept for backward compatibility and because some users may prefer that name.
 #'
 #' @inherit marginaleffects
@@ -345,22 +345,9 @@ avg_slopes <- function(model,
 
     # order of the first few paragraphs is important
     # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
+    # should probably not be nested too deeply in the call stack since we eval.parent() (not sure about this)
     scall <- substitute(newdata)
-    if (is.call(scall)) {
-        lcall <- as.list(scall)
-        fun_name <- as.character(scall)[1]
-        if (fun_name %in% c("datagrid", "datagridcf", "typical", "counterfactual")) {
-            if (!any(c("model", "newdata") %in% names(lcall))) {
-                lcall <- c(lcall, list("model" = model))
-                newdata <- eval.parent(as.call(lcall))
-            }
-        } else if (fun_name == "visualisation_matrix") {
-            if (!"x" %in% names(lcall)) {
-                lcall <- c(lcall, list("x" = get_modeldata))
-                newdata <- eval.parent(as.call(lcall))
-            }
-        }
-    }
+    newdata <- sanitize_newdata_call(scall, newdata, model)
 
 
     # Bootstrap
@@ -389,8 +376,5 @@ avg_slopes <- function(model,
         eps = eps,
         ...)
 
-    # overwrite call because otherwise we get the symbols sent to slopes()
-    attr(out, "call") <- match.call()
-
     return(out)
-}
\ No newline at end of file
+}
