@@ -1,9 +1,14 @@
+rm(list=ls())
+rm(list=ls(.GlobalEnv), envir = .GlobalEnv)
+
 EXPENSIVE <- FALSE
 
+options("tinyviztest_device" = "svglite")
+
 # libraries
 requiet <- function(package) {
     void <- capture.output(
-    pkg_available <<- tryCatch(suppressPackageStartupMessages(suppressWarnings(suppressMessages(tryCatch(
+    pkg_available <- tryCatch(suppressPackageStartupMessages(suppressWarnings(suppressMessages(tryCatch(
         isTRUE(require(package, warn.conflicts = FALSE, character.only = TRUE)),
         error = function(e) FALSE
     ))))))
@@ -20,7 +25,7 @@ if (isTRUE(suppressMessages(require("tinytest"))) && packageVersion("tinytest")
 }
 
 # common names of datasets, often assigned to global environment
-common <- c("dat", "tmp", "d", "k", "mod", "tmp1", "tmp2", "test1", "test2")
+common <- c("dat", "tmp", "d", "k", "mod", "tmp1", "tmp2", "test1", "test2", "threenum")
 suppressWarnings(rm(list = common, envir = .GlobalEnv))
 suppressWarnings(rm(list = common))
 
@@ -31,39 +36,6 @@ Sys.setenv(TZ="America/New_York")
 options(width = 10000)
 options(digits = 5)
 
-# important because otherwise testing so many packages is terrible
-dict <- c(
-    "contrast" = "emmeans",
-    "expect_error" = "tinytest",
-    "expect_true" = "tinytest",
-    "expect_equal" = "tinytest",
-    "expect_warning" = "tinytest",
-    "summary" = "base",
-    "lmer" = "lme4",
-    "s" = "gam",
-    "ar" = "stats",
-    "dof" = "parameters",
-    "marginal_effects" = "margins",
-    "kidney" = "brms",
-    "ngrps" = "brms",
-    "filter" = "dplyr",
-    "lag" = "dplyr",
-    "recode" = "dplyr",
-    "logit" = "boot",
-    "melanoma" = "boot",
-    "lizards" = "aod",
-    "rats" = "aod",
-    "aml" = "survival",
-    "mad" = "stats",
-    "sd" = "stats",
-    "var" = "stats"
-)
-conflicted::conflict_prefer_all("dplyr", quiet = TRUE)
-for (i in seq_along(dict)) {
-    conflicted::conflict_prefer(name = names(dict)[i], winner = dict[i], quiet = TRUE)
-}
-
-
 ON_CRAN <- !identical(Sys.getenv("R_NOT_CRAN"), "true")
 ON_GH <- identical(Sys.getenv("R_GH"), "true")
 ON_CI <- isTRUE(ON_CRAN) || isTRUE(ON_GH)
@@ -79,7 +51,6 @@ minver <- function(pkg, ver = NULL) {
     }
 }
 
-
 testing_path <- function(x) {
     wd <- tinytest::get_call_wd()
     if (isTRUE(wd != "")) {
