@@ -1,6 +1,9 @@
 source("helpers.R")
-using("marginaleffects")
 
 # factor in formula
 mod <- lm(mpg ~ hp + factor(cyl), data = mtcars)
 expect_warning(slopes(mod))
+
+
+
+rm(list = ls())
\ No newline at end of file
