@@ -66,51 +66,6 @@ expect_equivalent(nrow(tid), 4)
 expect_true("am" %in% colnames(tid))
 
 
-# marginaleffects poisson vs. margins
-dat <- mtcars
-mod <- glm(gear ~ cyl + am, family = poisson, data = dat)
-mfx <- slopes(
-    mod,
-    by = c("cyl", "am"),
-    newdata = datagrid(
-        cyl = dat$cyl,
-        am = dat$am,
-        grid_type = "counterfactual"))
-tid <- tidy(mfx)
-tid <- tid[order(tid$term, tid$cyl, tid$am),]
-mar <- margins(mod, at = list(cyl = unique(dat$cyl), am = unique(dat$am)))
-mar <- summary(mar)
-expect_equivalent(tid$estimate, mar$AME, tolerance = tol)
-expect_equivalent(tid$std.error, mar$SE, tolerance = tol_se)
-
-
-# comparisons poisson vs. margins
-dat <- mtcars
-dat$cyl <- factor(dat$cyl)
-dat$am <- as.logical(dat$am)
-mod <- glm(gear ~ cyl + am, family = poisson, data = dat)
-mfx <- comparisons(
-    mod,
-    by = c("cyl", "am"),
-    newdata = datagrid(
-        cyl = dat$cyl,
-        am = dat$am,
-        grid_type = "counterfactual"))
-
-mfx <- tidy(mfx)
-
-mfx <- mfx[order(mfx$term, mfx$contrast, mfx$cyl, mfx$am),]
-mar <- margins(mod, at = list(cyl = unique(dat$cyl), am = unique(dat$am)))
-mar <- summary(mar)
-expect_equivalent(mfx$estimate, mar$AME, tolerance = tol)
-expect_equivalent(mfx$std.error, mar$SE, tolerance = tol_se)
-
-
-# # input checks
-# mod <- lm(mpg ~ hp, mtcars)
-# expect_error(comparisons(mod, by = "am"), pattern = "newdata")
-# expect_error(slopes(mod, by = "am"), pattern = "newdata")
-
 
 # counterfactual margins at()
 dat <- mtcars
@@ -209,7 +164,56 @@ expect_equivalent(nrow(pre2), 96)
 
 mm <- marginal_means(
     mod,
-    by = FALSE,
     variables = "gear")
 expect_equivalent(nrow(mm), 3)
-expect_error(marginal_means(mod, by = TRUE, variables = "gear"))
\ No newline at end of file
+expect_error(marginal_means(mod, by = TRUE, variables = "gear"))
+
+
+# Issue #649: sort group when `by` is used
+mod <- lm(mpg ~ hp + factor(cyl), data = mtcars)
+pre <- predictions(mod, by = "cyl")
+expect_equivalent(pre$cyl, c(4, 6, 8))
+cmp <- predictions(mod, by = "cyl")
+expect_equivalent(cmp$cyl, c(4, 6, 8))
+
+
+# marginaleffects poisson vs. margins
+dat <- mtcars
+mod <- glm(gear ~ cyl + am, family = poisson, data = dat)
+mfx <- avg_slopes(
+    mod,
+    by = c("cyl", "am"),
+    newdata = datagrid(
+        cyl = unique,
+        am = unique,
+        grid_type = "counterfactual"))
+mar <- margins(mod, at = list(cyl = unique(dat$cyl), am = unique(dat$am)))
+mar <- summary(mar)
+# margins doesn't treat the binary am as binary automatically
+expect_equivalent(mfx$estimate[7:12], mar$AME[7:12], tolerance = tol)
+expect_equivalent(mfx$std.error[7:12], mar$SE[7:12], tolerance = tol_se)
+
+
+# comparisons poisson vs. margins
+dat <- mtcars
+dat$cyl <- factor(dat$cyl)
+dat$am <- as.logical(dat$am)
+mod <- glm(gear ~ cyl + am, family = poisson, data = dat)
+mfx <- comparisons(
+    mod,
+    by = c("cyl", "am"),
+    newdata = datagrid(
+        cyl = unique,
+        am = unique,
+        grid_type = "counterfactual"))
+
+mfx <- tidy(mfx)
+
+mfx <- mfx[order(mfx$term, mfx$contrast, mfx$cyl, mfx$am),]
+mar <- margins(mod, at = list(cyl = unique(dat$cyl), am = unique(dat$am)))
+mar <- summary(mar)
+expect_equivalent(mfx$estimate, mar$AME, tolerance = tol)
+expect_equivalent(mfx$std.error, mar$SE, tolerance = tol_se)
+
+
+rm(list = ls())
\ No newline at end of file
