@@ -42,4 +42,14 @@ pre29 <- predictions(mod, df = 29)
 preInf <- predictions(mod)
 expect_true(all(pre29$p.value > preInf$p.value))
 expect_true(all(pre29$conf.low < preInf$conf.low))
-expect_warning(predictions(mod, df = 12), pattern = "freedom")
\ No newline at end of file
+
+
+
+# Issue #627: print t instead of z in column names
+exit_if_not(requiet("tinyviztest"))
+mod <- lm(mpg ~ hp, mtcars)
+expect_snapshot_print(avg_comparisons(mod), "df-z")
+expect_snapshot_print(avg_comparisons(mod, df = 30), "df-t")
+
+
+rm(list = ls())
\ No newline at end of file
