@@ -4,7 +4,7 @@ using("marginaleffects")
 exit_if_not(requiet("lme4"))
 
 # lme4::lmer
-mod <- lmer(mpg ~ hp + (1 | gear), data = mtcars)
+mod <-lme4::lmer(mpg ~ hp + (1 | gear), data = mtcars)
 expect_inherits(slopes(mod), "marginaleffects")
 expect_warning(slopes(mod, blah = 2), pattern = "Github")
 
@@ -15,3 +15,5 @@ expect_inherits(slopes(mod), "marginaleffects")
 expect_warning(slopes(mod, blah = 2), pattern = "Github")
 
 
+
+rm(list = ls())
\ No newline at end of file
