@@ -24,7 +24,7 @@ em <- tidy(em)
 mfx <- slopes(
     model,
     variables = "PI",
-    newdata = datagrid(PI = 15, EH = 2, NV = 0, newdata = dat), 
+    newdata = datagrid(PI = 15, EH = 2, NV = 0), 
     type = "link")
 expect_equivalent(mfx$estimate, em$PI.trend)
 expect_equivalent(mfx$std.error, em$std.error, tolerance = .00001)
@@ -80,3 +80,5 @@ expect_slopes(mod, type = "probs")
 
 
 
+
+rm(list = ls())
\ No newline at end of file
