@@ -6,8 +6,9 @@ exit_if_not(requiet("MASS"))
 exit_if_not(requiet("margins"))
 
 # glmx: marginaleffects vs. margins
-d <- data.frame(x = runif(200, -1, 1))
-d$y <- rnbinom(200, mu = exp(0 + 3 * d$x), size = 1)
+tmp <- data.frame(x = runif(200, -1, 1))
+tmp$y <- rnbinom(200, mu = exp(0 + 3 * tmp$x), size = 1)
+d <- tmp
 model <- glmx(y ~ x, data = d, family = negative.binomial, 
           xlink = "log", xstart = 0)
 expect_slopes(model)
@@ -19,11 +20,16 @@ expect_true(expect_margins(mfx, mar, se = FALSE, tolerance = .001))
 
 # predictions: glmx: no validity check
 #skip_if_not_installed("insight", minimum_version = "0.17.1")
-d <- data.frame(x = runif(200, -1, 1))
-d$y <- rnbinom(200, mu = exp(0 + 3 * d$x), size = 1)
+tmp <- data.frame(x = runif(200, -1, 1))
+tmp$y <- rnbinom(200, mu = exp(0 + 3 * tmp$x), size = 1)
+d <- tmp
+dhead <- head(d)
 model <- glmx(y ~ x, data = d, family = negative.binomial,
           xlink = "log", xstart = 0)
 pred1 <- predictions(model)
-pred2 <- predictions(model, newdata = head(d))
-expect_predictions(pred1, n_row = nrow(d))
+pred2 <- predictions(model, newdata = dhead)
+expect_predictions(pred1, n_row = dhead)
 expect_predictions(pred2, n_row = 6)
+
+
+source("helpers.R")
\ No newline at end of file
