@@ -13,11 +13,8 @@ dat <- Transport
 void <- capture.output(
     model <- mclogit(cbind(resp, suburb) ~ distance + cost, data = Transport)
 )
-# type = "response" produces 0 dydx and standard error. Not sure why
-# because `get_predict(newdata)` seems to work
-expect_error(slopes(model, type = "response"), pattern = "type. argument")
 # type = "link" works
-suppressWarnings(expect_slopes(model, type = "link", n_unique = 1))
+expect_slopes(model, type = "link", n_unique = 1)
 pred <- predictions(model, type = "link")
 expect_predictions(pred)
 
@@ -67,7 +64,7 @@ void <- capture.output(suppressWarnings(
 p1 <- predict(mod, type = "response", se.fit = TRUE)
 p2 <- predictions(mod)
 expect_equivalent(p1$fit[160,], p2[p2$rowid == 160, "estimate"])
-expect_equivalent(p1$se.fit[160,], p2[p2$rowid == 160, "std.error"], tolerance = .001)
+expect_equivalent(p1$se.fit[160,], p2[p2$rowid == 160, "std.error"], tolerance = .01)
 
 # link
 p1 <- predict(mod, type = "link", se.fit = TRUE)
@@ -84,4 +81,8 @@ p3 <- data.frame(
     mode = "latent",
     level = 0.95))
 expect_equivalent(p3$emmean, p2[p2$rowid == 160, "estimate"])
-expect_equivalent(p3$SE, p2[p2$rowid == 160, "std.error"])
\ No newline at end of file
+expect_equivalent(p3$SE, p2[p2$rowid == 160, "std.error"])
+
+
+
+rm(list = ls())
\ No newline at end of file
