@@ -1,14 +1,13 @@
 source("helpers.R")
 using("marginaleffects")
-library(tinytest)
-
+exit_if_not(EXPENSIVE)
 exit_if_not(!ON_CI)
 exit_if_not(packageVersion("base") >= "4.2.0")
 
 exit_if_not(requiet("MASS"))
 exit_if_not(requiet("ordinal"))
 
-dat <<- read.csv(
+dat <- read.csv(
     "https://vincentarelbundock.github.io/Rdatasets/csv/MASS/housing.csv",
     stringsAsFactors = TRUE)
 
@@ -27,7 +26,7 @@ expect_equivalent(unknown$std.error, known$std.error, tolerance = .00001)
 # marginaleffects: protect against corner cases
 # do not convert numeric to factor in formula
 stata <- readRDS(testing_path("stata/stata.rds"))[["MASS_polr_01"]]
-dat <<- read.csv(testing_path("stata/databases/MASS_polr_01.csv"))
+dat <- read.csv(testing_path("stata/databases/MASS_polr_01.csv"))
 mod <- ordinal::clm(factor(y) ~ x1 + x2, data = dat)
 expect_error(slopes(mod), pattern = "Please convert the variable to factor")
 
@@ -37,7 +36,7 @@ expect_error(slopes(mod), pattern = "Please convert the variable to factor")
 stata <- readRDS(testing_path("stata/stata.rds"))[["MASS_polr_01"]]
 dat <- read.csv(testing_path("stata/databases/MASS_polr_01.csv"))
 dat$y <- factor(dat$y)
-dat <<- dat
+dat <- dat
 mod <- ordinal::clm(y ~ x1 + x2, data = dat)
 mfx <- slopes(mod)
 mfx <- tidy(mfx)
@@ -54,7 +53,7 @@ tab26 <- with(tmp, table("Product" = PROD, "Response" = SURENESS))
 dimnames(tab26)[[2]] <- c("Sure", "Not Sure", "Guess", "Guess", "Not Sure", "Sure")
 dat26 <- expand.grid(sureness = as.factor(1:6), prod = c("Ref", "Test"))
 dat26$wghts <- c(t(tab26))
-dat26 <<- dat26
+dat26 <- dat26
 m1 <- clm(sureness ~ prod, scale = ~prod, data = dat26, weights = wghts, link = "logit")
 m2 <- update(m1, link = "probit")
 m3 <- update(m1, link = "cloglog")
@@ -68,21 +67,5 @@ expect_slopes(m5, n_unique = 6)
 
 
 
-exit_file('works interactively')
-
-dat <- read.csv(
-    "https://vincentarelbundock.github.io/Rdatasets/csv/MASS/housing.csv",
-    stringsAsFactors = TRUE)
-mod <- clm(Sat ~ Infl + Type + Cont, weights = Freq, data = dat)
-
-p <- predictions(mod, newdata = dat) # test environment
-expect_inherits(p, "predictions")
-
-# plot
-mfx <- slopes(mod, newdata = dat) # test environment
-p <- plot(mfx)
-expect_inherits(p, "gg")
-p <- plot_slopes(mod, effect = "Infl", condition = "Type")
-expect_inherits(p, "gg")
-p <- plot_predictions(mod, condition = "Type")
-expect_inherits(p, "gg")
\ No newline at end of file
+source("helpers.R")
+rm(list = ls())
\ No newline at end of file
