@@ -10,20 +10,20 @@ tol_se <- .01 # BDR emergency email about tiny numerical differences
 
 dat <- read.csv("https://vincentarelbundock.github.io/Rdatasets/csv/plm/Grunfeld.csv")
 dat$X <- NULL
-dat <- pdata.frame(dat)
+dat <<- pdata.frame(dat)
 pool <- plm(inv ~ value * capital, data = dat, model = "pooling")
 swamy <- plm(
     inv ~ value * capital,
     data = dat,
-    model = "random", effect = "individual")
+    model = "random", variables = "individual")
 amemiya <- plm(
     inv ~ value * capital,
     data = dat, model = "random", random.method = "amemiya",
-    effect = "twoways")
+    variables = "twoways")
 walhus <- plm(
     inv ~ value * capital,
     data = dat, model = "random", random.method = "walhus",
-    effect = "twoways")
+    variables = "twoways")
 
 ### marginaleffects
 
@@ -78,7 +78,7 @@ expect_equivalent(mfx$std.error, mar$std.error, tolerance = tol_se)
 # # within error
 # # within model are not supported by `predict.plm`
 # stata <- readRDS(testing_path("stata/stata.rds"))$plm_within
-# mod <- plm(inv ~ value * capital, data = dat, model = "within", effect = "twoways")
+# mod <- plm(inv ~ value * capital, data = dat, model = "within", variables = "twoways")
 # expect_error(slopes(mod), pattern = "Unable")
 
 
@@ -91,3 +91,8 @@ pred2 <- predictions(pool, newdata = head(dat))
 expect_predictions(pred1, n_row = nrow(dat))
 expect_predictions(pred2, n_row = 6)
 
+
+
+
+source("helpers.R")
+rm(list = ls())
\ No newline at end of file
