@@ -31,9 +31,5 @@ expect_equivalent(exp(cmp1$conf.high), cmp2$conf.high)
 # expect_equivalent(exp(tid1$conf.low), tid2$conf.low)
 # expect_equivalent(exp(tid1$conf.high), tid2$conf.high)
 
-# string shortcuts and printout
-mod <- lm(mpg ~ hp, mtcars)
-cmp <- comparisons(mod, transform_post = "exp")
-expect_inherits(cmp, "comparisons")
-pri <- capture.output(summary(cmp))
-expect_equivalent(sum(grepl(" exp ", pri)), 1)
+
+rm(list = ls())
\ No newline at end of file
